.workflowlist {
    display: flex;
    flex-direction: column;
    gap:0.05rem;
}

.workflowlist__item {
    padding: 0.75rem;
    border-radius: 0.25rem;
    background: var(--neutral-0);
    border: 1px solid var(--neutral-200);
    text-decoration: none;
}

.workflowlist__item:hover {
    background: var(--neutral-100);
    transition-property: background;
    transition-duration: 150ms;
    cursor: pointer;
}
.workflowlist__item__title {
    display: flex;
    align-items: center;
    gap: 0.5rem;
    text-decoration: none;
    margin-bottom: 0.25rem;

}
.workflowlist__item__title::before {
    content: url("data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%2218%22%20height%3D%2218%22%20viewBox%3D%220%200%2024%2024%22%20fill%3D%22none%22%20stroke%3D%22%23737373%22%20stroke-width%3D%222%22%20stroke-linecap%3D%22round%22%20stroke-linejoin%3D%22round%22%20class%3D%22lucide%20lucide-workflow-icon%20lucide-workflow%22%3E%3Crect%20width%3D%228%22%20height%3D%228%22%20x%3D%223%22%20y%3D%223%22%20rx%3D%222%22%2F%3E%3Cpath%20d%3D%22M7%2011v4a2%202%200%200%200%202%202h4%22%2F%3E%3Crect%20width%3D%228%22%20height%3D%228%22%20x%3D%2213%22%20y%3D%2213%22%20rx%3D%222%22%2F%3E%3C%2Fsvg%3E");
}

.workflowlist__item__id {
    color: var(--neutral-400);
    font-size: 0.675rem;
    margin-left: 1.5rem;
    text-decoration: none;
}
