{% macro common_head_macro() -%}
  <link rel="preconnect" href="https://fonts.googleapis.com">
  <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
  <link href="https://fonts.googleapis.com/css2?family=Inter:ital,opsz,wght@0,14..32,100..900;1,14..32,100..900&display=swap" rel="stylesheet">
  <link rel="stylesheet" href="/static/index.css">
  <link rel="stylesheet" href="/static/workflows.html.css">
   <link rel="stylesheet" href="/static/macros.breadcrumbs.html.css">


   <link rel="stylesheet" href="/static/normalize.css">
  <script src="/static/tokens.js"></script>
  <script src="/static/utils.js"></script>
  <script src="/static/vis-network.min.js"></script>
  <script src="/static/network.js"></script>
  <script src="/static/eventstream.js"></script>
  <link rel="icon" href="/static/favicon.svg" type="image/svg+xml">
{%- endmacro %}
