* {
    margin: 0;
    padding: 0;
}

ul {
    list-style: none;
}

li {
    margin: 0.25rem 0rem;
    list-style: none;
}

a {
    all: unset;
}
a:hover {
    cursor: pointer;
}

body {
    font-size: 0.875rem;
    background-color: var(--neutral-50);
    font-family: 'Inter', -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, sans-serif;
}

main {
    padding: 1rem 1.5rem;
}




html {
    --neutral-0: #ffffff;
    --neutral-50:#fafafa;
    --neutral-100:#f4f4f5;
    --neutral-200:  #e4e4e7;
    --neutral-300:  #d4d4d8;
    --neutral-400:  #a1a1aa;
    --neutral-500:  #71717a;
    --neutral-600:  #52525b;
    --neutral-700:  #3f3f46;
    --neutral-800: #27272a;
    --neutral-900:  #18181b;
    --neutral-950:  #09090b;
    --green-primary: #bbf7d0;
    --red-primary: #fca5a5;
    --amber-primary: #fde68a;
    --primary: #3b82f6;


}




.button {
    padding: 0.5rem 0.75rem;
    background-color: var(--neutral-0);
    border-radius: 0.5rem;
    color: var(--neutral-700);
    font-size: 0.75rem;
    font-weight: 500;
    letter-spacing: -0.02em;
    text-decoration: none;
    display: block;
    width: min-content;
    text-wrap: nowrap;
    border: 1px solid var(--neutral-300);
    display: flex;
    align-items: center;
    justify-content: center;
    gap:0.25rem;
}

.button:hover {
    background-color: var(--neutral-100);
    cursor: pointer;
}

#mynetwork {
    width: 100%;
    height:calc(100vh - 10.25rem);
    border: 1px solid lightgray;
    border-radius: 0.5rem;
    background-color: var(--neutral-100);
    background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='100' height='100' viewBox='0 0 100 100'%3E%3Cg fill-rule='evenodd'%3E%3Cg fill='%23d4d4d8' fill-opacity='0.4'%3E%3Cpath opacity='.5' d='M96 95h4v1h-4v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9zm-1 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-9-10h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm9-10v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-9-10h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm9-10v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-9-10h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm9-10v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-10 0v-9h-9v9h9zm-9-10h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9zm10 0h9v-9h-9v9z'/%3E%3Cpath d='M6 5V0H5v5H0v1h5v94h1V6h94V5H6z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E");
}





