{% from "macros/breadcrumbs.html" import breadcrumbs_macro with context %}
{% from "macros/common_head.html" import common_head_macro with context %}
{% from "macros/header.html" import header_macro with context %}
<html>
  <head>
    <title>Tierkreis visualization: node unavailable</title>
      {{ common_head_macro() }}
  </head>
  <body>
    {{ header_macro() }}
    <main>
      {{ breadcrumbs_macro(breadcrumbs) }}
      <h1 style="font-size: 1.75rem;
    font-weight: 500;">Node unavailable</h1>
     
    <p> The node at the path <b>{{ node_location }}</b> is not started and has no data available.</p>
    </main>
  </body>
</html>
