{% from "macros/common_head.html" import common_head_macro with context %}
{% from "macros/header.html" import header_macro with context %}
<html>
<head>
    <title>Tierkreis visualization</title>
     {{ common_head_macro() }}

</head>
<body>
  {{ header_macro() }}
  <main>
    <a href="/workflows">All running workflows</a>
    </main>
</body>
</html>
