.badge {
    padding: 0.25rem 0.5rem;
    background-color: var(--neutral-0);
    border-radius: 0.5rem;
    color: var(--neutral-700);
    font-size: 0.75rem;
    font-weight: 500;
    letter-spacing: -0.02em;
    text-decoration: none;
    display: block;
    width: min-content;
    text-wrap: nowrap;
    border: 1px solid var(--neutral-300);

}
.badge:hover {
    background-color: var(--neutral-100);
    transition-property: background-color;
    transition-duration: 150ms;
}
