{% from "macros/breadcrumbs.html" import breadcrumbs_macro with context %}
{% from "macros/common_head.html" import common_head_macro with context %}
{% from "macros/header.html" import header_macro with context %}
<html>

<head>
  <title>Tierkreis visualization: MAP node</title>
  {{ common_head_macro() }}

</head>

<body class="graph-bg">
  {{ header_macro() }}
  <main>
  {{ breadcrumbs_macro(breadcrumbs, true) }}
  <div id="mynetwork"></div>

  <script type="text/javascript">
    let [network, nodes, edges] = createNetwork({{ nodes|safe }}, {{ edges|safe }}, "M");
    network.setOptions({
      edges: {  hidden: false, physics: true, color: {opacity: 0}, font: {color: "white"} }
    })
    connectToStream("{{ url|safe }}", nodes, edges);
  </script>
  </main>
</body>

</html>
