{% from "macros/common_head.html" import common_head_macro with context %}
{% from "macros/header.html" import header_macro with context %}
{% from "macros/breadcrumbs.html" import breadcrumbs_macro with context %}
<html>
  <head>
    <title>Tierkreis visualization: workflows</title>
    {{ common_head_macro() }}
  </head>
  <body>
    {{ header_macro() }}
    <main>
      {{ breadcrumbs_macro([["/workflows"]]) }}
    <ul class="workflowlist">
      {% for workflow in workflows %}

        <li >
        <a  href="/workflows/{{ workflow.id }}/nodes/-">
      <div class="workflowlist__item">
              <div class="workflowlist__item__title"
                >{{ workflow.name }}-{{ workflow.id_int }}</div
              >
              <span class="workflowlist__item__id" style="text-decoration:none;">{{ workflow.id }}</span>
              </div>
          </a>
        </li>

      {% endfor %}
    </ul>
    </main>
  </body>
</html>
